@@ -11,7 +11,7 @@
 #'
 #' @inheritParams run
 #'
-#' @return An object of class `list` representing the result of the command
+#' @returns An object of class `list` representing the result of the command
 #'   execution. Contains information about the standard output, standard error,
 #'   and exit status of the command.
 #'
@@ -22,8 +22,7 @@
 #'   # Run 'python' with a script in 'my-env' environment
 #'   condathis::run_bin(
 #'     "python", "-c", "import sys; print(sys.version)",
-#'     env_name = "my-env",
-#'     verbose = "output"
+#'     env_name = "my-env"
 #'   )
 #'
 #'   # Run 'ls' command with additional arguments
@@ -33,14 +32,21 @@
 #'
 #' @export
 run_bin <- function(
-    cmd,
-    ...,
-    env_name = "condathis-env",
-    verbose = "silent",
-    error = c("cancel", "continue"),
-    stdout = "|",
-    stderr = "|",
-    stdin = NULL) {
+  cmd,
+  ...,
+  env_name = "condathis-env",
+  verbose = c(
+    "output",
+    "silent",
+    "cmd",
+    "spinner",
+    "full"
+  ),
+  error = c("cancel", "continue"),
+  stdout = "|",
+  stderr = "|",
+  stdin = NULL
+) {
   error <- rlang::arg_match(error)
   if (isTRUE(identical(error, "cancel"))) {
     error_var <- TRUE
@@ -48,10 +54,14 @@ run_bin <- function(
     error_var <- FALSE
   }
 
-  verbose_list <- parse_strategy_verbose(strategy = verbose)
-  verbose_cmd <- verbose_list$cmd
+  rlang::check_dots_unnamed()
+
+  verbose_list <- parse_strategy_verbose(verbose = verbose)
+
   verbose_output <- verbose_list$output
-  spinner_flag <- rlang::is_interactive()
+  if (isFALSE(stderr %in% c("|", ""))) {
+    verbose_output <- FALSE
+  }
 
   env_dir <- get_env_dir(env_name = env_name)
   cmd_path <- fs::path(env_dir, "bin", cmd)
@@ -69,9 +79,11 @@ run_bin <- function(
       `CONDA_SHLVL` = "0",
       `MAMBA_SHLVL` = "0",
       `CONDA_ENVS_PATH` = "",
+      `CONDA_ENVS_DIRS` = NULL,
       `CONDA_ROOT_PREFIX` = "",
       `CONDA_PREFIX` = "",
       `MAMBA_ENVS_PATH` = "",
+      `MAMBA_ENVS_DIRS` = "",
       `MAMBA_ROOT_PREFIX` = "",
       `MAMBA_PREFIX` = "",
       `CONDARC` = "",
@@ -80,6 +92,8 @@ run_bin <- function(
       `MAMBA_PROMPT_MODIFIER` = "",
       `CONDA_DEFAULT_ENV` = "",
       `MAMBA_DEFAULT_ENV` = "",
+      `CONDA_PKGS_DIRS` = "",
+      `MAMBA_PKGS_DIRS` = "",
       `R_HOME` = ""
     )
   )
@@ -96,8 +110,8 @@ run_bin <- function(
       processx::run(
         command = cmd_path,
         args = args_vector,
-        spinner = spinner_flag,
-        echo_cmd = verbose_cmd,
+        spinner = verbose_list$spinner_flag,
+        echo_cmd = verbose_list$cmd,
         echo = verbose_output,
         stdout = stdout,
         stderr = stderr,
