@@ -6,17 +6,27 @@
 #'
 #' @keywords internal
 #' @noRd
-run_internal_native <- function(cmd,
-                                ...,
-                                env_name = "condathis-env",
-                                verbose = FALSE,
-                                error = c("cancel", "continue"),
-                                stdout = "|",
-                                stderr = "|",
-                                stdin = NULL) {
+run_internal_native <- function(
+  cmd,
+  ...,
+  env_name = "condathis-env",
+  verbose = c(
+    "output",
+    "silent",
+    "cmd",
+    "spinner",
+    "full"
+  ),
+  error = c("cancel", "continue"),
+  stdout = "|",
+  stderr = "|",
+  stdin = NULL
+) {
   if (isTRUE(base::Sys.info()["sysname"] == "Windows")) {
     micromamba_bat_path <- fs::path(
-      get_install_dir(), "condabin", "micromamba",
+      get_install_dir(),
+      "condabin",
+      "micromamba",
       ext = "bat"
     )
     if (isFALSE(fs::file_exists(micromamba_bat_path))) {
@@ -25,20 +35,28 @@ run_internal_native <- function(cmd,
           native_cmd(
             conda_cmd = "run",
             conda_args = c("-n", "condathis-env"),
-            cmd = "dir", verbose = FALSE, stdout = NULL
+            "dir",
+            verbose = "silent",
+            stdout = NULL
           )
         }
       )
       base::rm(catch_res)
       mamba_bat_path <- fs::path(
-        get_install_dir(), "condabin", "mamba",
+        get_install_dir(),
+        "condabin",
+        "mamba",
         ext = "bat"
       )
       if (
         isTRUE(fs::file_exists(mamba_bat_path)) &&
           isFALSE(fs::file_exists(micromamba_bat_path))
       ) {
-        fs::file_copy(mamba_bat_path, micromamba_bat_path, overwrite = TRUE)
+        fs::file_copy(
+          path = mamba_bat_path,
+          new_path = micromamba_bat_path,
+          overwrite = TRUE
+        )
       }
     }
   }
@@ -48,7 +66,7 @@ run_internal_native <- function(cmd,
       "-n",
       env_name
     ),
-    cmd = cmd,
+    cmd,
     ...,
     verbose = verbose,
     error = error,
